==> gnome-photos-3.13.4.tar.xz: gnome-photos-3.13.4/src/photos-print-notification.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_PRINT_NOTIFICATION_H
#define PHOTOS_PRINT_NOTIFICATION_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define PHOTOS_TYPE_PRINT_NOTIFICATION (photos_print_notification_get_type ())

#define PHOTOS_PRINT_NOTIFICATION(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotification))

#define PHOTOS_PRINT_NOTIFICATION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotificationClass))

#define PHOTOS_IS_PRINT_NOTIFICATION(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION))

#define PHOTOS_IS_PRINT_NOTIFICATION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
   PHOTOS_TYPE_PRINT_NOTIFICATION))

#define PHOTOS_PRINT_NOTIFICATION_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotificationClass))

typedef struct _PhotosPrintNotification        PhotosPrintNotification;
typedef struct _PhotosPrintNotificationClass   PhotosPrintNotificationClass;
typedef struct _PhotosPrintNotificationPrivate PhotosPrintNotificationPrivate;

struct _PhotosPrintNotification
{
  GtkGrid parent_instance;
  PhotosPrintNotificationPrivate *priv;
};

struct _PhotosPrintNotificationClass
{
  GtkGridClass parent_class;
};

GType               photos_print_notification_get_type           (void) G_GNUC_CONST;

GtkWidget          *photos_print_notification_new                (GtkPrintOperation *print_op);

G_END_DECLS

#endif /* PHOTOS_PRINT_NOTIFICATION_H */

==> gnome-photos_3.18.2.orig.tar.xz: gnome-photos-3.18.2/src/photos-print-notification.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_PRINT_NOTIFICATION_H
#define PHOTOS_PRINT_NOTIFICATION_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define PHOTOS_TYPE_PRINT_NOTIFICATION (photos_print_notification_get_type ())

#define PHOTOS_PRINT_NOTIFICATION(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotification))

#define PHOTOS_PRINT_NOTIFICATION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotificationClass))

#define PHOTOS_IS_PRINT_NOTIFICATION(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION))

#define PHOTOS_IS_PRINT_NOTIFICATION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
   PHOTOS_TYPE_PRINT_NOTIFICATION))

#define PHOTOS_PRINT_NOTIFICATION_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
   PHOTOS_TYPE_PRINT_NOTIFICATION, PhotosPrintNotificationClass))

typedef struct _PhotosPrintNotification        PhotosPrintNotification;
typedef struct _PhotosPrintNotificationClass   PhotosPrintNotificationClass;
typedef struct _PhotosPrintNotificationPrivate PhotosPrintNotificationPrivate;

struct _PhotosPrintNotification
{
  GtkGrid parent_instance;
  PhotosPrintNotificationPrivate *priv;
};

struct _PhotosPrintNotificationClass
{
  GtkGridClass parent_class;
};

GType               photos_print_notification_get_type           (void) G_GNUC_CONST;

void                photos_print_notification_new                (GtkPrintOperation *print_op);

G_END_DECLS

#endif /* PHOTOS_PRINT_NOTIFICATION_H */
